@@ -1,7 +1,9 @@
 from .outliers import mad_outliers
 from .dummies import dummy_code, dummy_top
 from .missing_fill import missing_fill
+from .missing_check import missing_check
 from .feature_reduction import drop_categorical, remove_low_variation, dv_proxies, correlation_reduction
 from .split_data import split_data
 from .mars_modeling import mars_modeling
 from .model_metrics import model_metrics
+from .insights import marginal_effects, prescriptions
