@@ -191,7 +191,7 @@ def marginal_effects(model, x_test, dv_description, field_labels = None):
                         
                         pass
                     
-                    #If no lower mean_zero value and hinge is a negative value set to 10x "jump" value bwelow hinge value
+                    #If no lower mean_zero value and hinge is a negative value set to 10x "jump" value below hinge value
                     else:
                         
                         mean_zero[v] = bf.loc[idx, 'hinge'] - (bf.loc[idx, 'increase_value']*10)
@@ -236,7 +236,7 @@ def marginal_effects(model, x_test, dv_description, field_labels = None):
     return bf
 
 
-def prescriptions(model, input_df, scored_df, actionable_fields, dv_description, field_labels=None, returned_insights=5):
+def prescriptions(model, input_df, scored_df, actionable_fields, dv_description, field_labels=None, returned_insights=5, only_actionable=False, explanation_fields='all'):
 
     import pandas as pd
     import numpy as np
@@ -325,6 +325,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
             input_change_prob['feature'] = v
             input_change_prob['direction'] = 'Decreasing'
             input_change_prob['increase_value'] = increase_value
+            
             input_change_prob['type'] = 'actionable'
             input_change_prob['binary'] = binary_flag
 
@@ -392,7 +393,7 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     change_score['effect_pct_abs'] = change_score['effect_pct'].abs()
     
     #Remove features with zero effect
-    change_score = change_score[(change_score['effect_pct_abs'] > 0.005)]
+    change_score = change_score[(change_score['effect_pct_abs'] > 0.0051)]
         
     #Sort by index (asc), type (asc), absoulte value of effect (desc)
     change_score.sort_values(by=[change_score.index.name, 'type', 'effect_pct_abs'], axis=0, ascending=(True, True, False), inplace=True)
@@ -408,19 +409,23 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
         
     else:
         change_score['feature_label'] = change_score['feature']
+        
+    
+    #Zero fill missing values so insights will format numbers properly due to no missing values
+    change_score['increase_value'] = change_score['increase_value'].fillna(0)
+    change_score['feature_value'] = change_score['feature_value'].fillna(0)
     
     
     #Add insight text
     #For Actionable Features    
-    #Remove "by step_jump" and make to increase relative to current score
-    change_score['insight'] = np.where(change_score['binary'] == False,
-                                       change_score['direction']+" \'"+change_score['feature_label']+f"\' will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", (change_score['effect_pct']*100).astype(int).astype(str)+"%."),
-                                       "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", (change_score['effect_pct']*100).astype(int).astype(str)+"%.")
+    change_score['insight'] = np.where((change_score['binary'] == False) & (change_score['type'] == 'actionable'),
+                                       change_score['direction']+" \'"+change_score['feature_label']+"\' by "+np.where(change_score['increase_value'] >= 1, change_score['increase_value'].astype(int).astype(str), change_score['increase_value'].astype(str))+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"%.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%."), #For non-binary
+                                       "Changing the value of \'"+change_score['feature_label']+"\' to "+np.where(change_score['direction']=='Increasing', '\'Yes\'', '\'No\'')+f" will increase {dv_description} by "+np.where(change_score['effect_pct'] > 1, np.round((change_score['effect_pct']+1),1).astype(str)+"x.", np.round(change_score['effect_pct']*100,0).astype(int).astype(str)+"%.") #For binary 
                                        )     
     
     #For Explainable (not-Actionable) Features
-    change_score['insight'] = np.where(change_score['type'] == 'explainable',
-                                       "'"+change_score['feature_label']+"\' = "+round(change_score['feature_value'],1).astype(str)+", which "+np.where(change_score['effect_pct'] > 1, 'greatly ', np.where(change_score['effect_pct'] < .1, 'somewhat ', ''))+change_score['direction']+f" {dv_description}.",
+    change_score['insight'] = np.where((change_score['type'] == 'explainable') & (change_score['binary'] == False),
+                                       "'"+change_score['feature_label']+"\' = "+np.where(change_score['feature_value'] >= 1, change_score['feature_value'].astype(int).astype(str),np.round(change_score['feature_value'],1).astype(str))+", which "+np.where(change_score['effect_pct'] > 1, 'greatly ', np.where(change_score['effect_pct'] < .1, 'somewhat ', ''))+change_score['direction']+f" {dv_description}.",
                                        change_score['insight']
                                        )
     
@@ -430,6 +435,18 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
                                        change_score['insight']
                                        )
     
+    
+    #Filter to only actionable if called for
+    if only_actionable is True:
+        change_score = change_score[change_score['type'] == 'actionable']
+
+        
+    #Filter to only specific explanations
+    if type(explanation_fields) == list:
+        change_score = change_score[(change_score['type'] == 'actionable') | (change_score['feature'].isin(explanation_fields))]
+        
+    #display(change_score)
+    
     #Cleanup
     change_score = change_score[['feature', 'type', 'effect', 'effect_pct', 'insight']]   
 
@@ -438,6 +455,5 @@ def prescriptions(model, input_df, scored_df, actionable_fields, dv_description,
     
     #Aggregate to index-level, collasping index to one line
     scores_w_insights = change_score.groupby([change_score.index.name])['insight'].apply(' '.join)
-    #display(scores_w_insights)
         
     return scores_w_insights 
\ No newline at end of file
