@@ -10,6 +10,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     import numpy as np
     from sklearn import metrics
     import warnings
+    import seaborn as sns
     
     pd.set_option('display.float_format', lambda x: '%.5f' % x)
     
@@ -22,7 +23,8 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         features.sort_values(by=['importance'], ascending=False, inplace=True)
         display(features)
         
-    if algo in ('rf', 'xgb'):
+    if algo == 'xgb':
+        
         import shap
         # explain the model's predictions using SHAP
         explainer = shap.Explainer(model)
@@ -42,10 +44,25 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         # Assign shap values based on test dataset
         shap_values = explainer.shap_values(x_test)
         
-        # Make plot
-        shap.summary_plot(shap_values[1], x_test)  
-        
+            
+    if algo == 'rf': 
     
+        importance = pd.DataFrame(model.feature_importances_)
+
+        features = pd.DataFrame(x_test.columns)
+
+        result = pd.concat([features, importance], axis=1)
+        result.columns = ['features', 'importance']
+        top20_features = result.sort_values(by=['importance'], ascending=False).head(20)
+        display(top20_features)
+
+
+        sns.set_theme(style="whitegrid")
+        sns.set(rc={'figure.figsize':(11,8)})
+        ax = sns.barplot(x="features", y="importance", data=top20_features)
+        ax.set_xticklabels(ax.get_xticklabels(), rotation=45, ha="right")
+        ax.set(title = "Top 20 features for account expansion")
+   
     # TRAIN DATA: Get Predicted and Actual
     score_train = model.predict_proba(x_train)
     score_train = pd.DataFrame([item[1] for item in score_train], columns=['predicted'])
@@ -203,6 +220,7 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         
     if show_graphs:
         
+        import matplotlib
         import matplotlib.pyplot as plt
         import seaborn as seaborn
         
